#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME=$(uci get emby.@main[0].image_name 2>/dev/null)
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME="lscr.io/linuxserver/emby:latest"
}

do_install_detail() {
  local config=$(uci get emby.@main[0].config_path 2>/dev/null)
  local port=$(uci get emby.@main[0].http_port 2>/dev/null)
  local tvshows=$(uci get emby.@main[0].tvshows_path 2>/dev/null)
  local movies=$(uci get emby.@main[0].movies_path 2>/dev/null)

  LAN_IP=$(uci get network.lan.ipaddr)
  LAN_IP="${LAN_IP%/*}"

  if [ -z "$config" ] || [ -z "$tvshows" ] || [ -z "$movies" ]; then
    echo "Paths for config, tvshows, or movies are empty!"
    exit 1
  fi

  [ -z "$port" ] && port=8096

  rm -R /opt/docker2/compose/emby-app
  mkdir /opt/docker2/compose/emby-app

  touch /opt/docker2/compose/emby-app/docker-compose.yml
  cat > /opt/docker2/compose/emby-app/docker-compose.yml <<EOF
version: "2.1"
services:
  emby:
    image: $IMAGE_NAME
    container_name: emby
    environment:
      - PUID=1000
      - PGID=1000
      - TZ=Etc/UTC
    volumes:
      - ./config:/config
      - $config:/data/tvshows
      - $config:/data/movies
    ports:
      - $port:8096
    restart: unless-stopped
EOF

  docker-compose -f /opt/docker2/compose/emby-app/docker-compose.yml up -d

  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="Emby"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu
}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install Emby"
  echo "      upgrade                Upgrade Emby"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart Emby"
  echo "      status                 Emby status"
  echo "      port                   Emby port"
}

case ${ACTION} in
  "install"|"upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    get_image
    docker-compose -f /opt/docker2/compose/emby-app/docker-compose.yml down
  ;;
  "start"|"stop"|"restart")
    docker-compose -f /opt/docker2/compose/emby-app/docker-compose.yml ${ACTION}
  ;;
  "status")
    get_image
    docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Status}}'
  ;;
  "port")
    get_image
    docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
